package com.zehong.system.service;

import java.util.List;
import com.zehong.system.domain.TRectifyPersonGroupInfo;

/**
 * 整改人员分组信息Service接口
 * 
 * @author zehong
 * @date 2026-07-16
 */
public interface ITRectifyPersonGroupInfoService 
{
    /**
     * 查询整改人员分组信息
     * 
     * @param groupId 整改人员分组信息ID
     * @return 整改人员分组信息
     */
    public TRectifyPersonGroupInfo selectTRectifyPersonGroupInfoById(Long groupId);

    /**
     * 查询整改人员分组信息列表
     * 
     * @param tRectifyPersonGroupInfo 整改人员分组信息
     * @return 整改人员分组信息集合
     */
    public List<TRectifyPersonGroupInfo> selectTRectifyPersonGroupInfoList(TRectifyPersonGroupInfo tRectifyPersonGroupInfo);

    /**
     * 新增整改人员分组信息
     * 
     * @param tRectifyPersonGroupInfo 整改人员分组信息
     * @return 结果
     */
    public int insertTRectifyPersonGroupInfo(TRectifyPersonGroupInfo tRectifyPersonGroupInfo);

    /**
     * 修改整改人员分组信息
     * 
     * @param tRectifyPersonGroupInfo 整改人员分组信息
     * @return 结果
     */
    public int updateTRectifyPersonGroupInfo(TRectifyPersonGroupInfo tRectifyPersonGroupInfo);

    /**
     * 批量删除整改人员分组信息
     * 
     * @param groupIds 需要删除的整改人员分组信息ID
     * @return 结果
     */
    public int deleteTRectifyPersonGroupInfoByIds(Long[] groupIds);

    /**
     * 删除整改人员分组信息信息
     * 
     * @param groupId 整改人员分组信息ID
     * @return 结果
     */
    public int deleteTRectifyPersonGroupInfoById(Long groupId);
}
